@@ -16,9 +16,13 @@ DIFFICULTY = MIN_LEN
 def mine(timeout=1000000000, min_len=MIN_LEN):
     print("Setting difficulty to min_len=" + str(min_len), flush=True)
     time.sleep(1)
-    print("This may take all day ...",flush=True)
-    time.sleep(1)
-    print("...but it will create a key which gives your access to the world's most sophisticated statistical contest.",flush=True)
+    print("This may take all day.",flush=True)
+    time.sleep(5)
+    print("But it will create a key which gives your access to the world's most sophisticated statistical contest...",flush=True)
+    time.sleep(5)
+    print("... sponsored by one of the world's most mathematically sophisticated investment firms.",flush=True)
+    time.sleep(5)
+    print("Going dark now. The next message you will see will be the prize.",flush=True)
     gen = Memorable.key_generator(min_len=min_len, timeout=timeout, verbose=True)
     for report in gen:
         print(report, flush=True)
